==> huaweicloudsdkeihealth-3.1.33-py2.py3-none-any.whl: huaweicloudsdkeihealth/v1/model/publish_data_response.py <==
# coding: utf-8

import re
import six


from huaweicloudsdkcore.sdk_response import SdkResponse
from huaweicloudsdkcore.utils.http_utils import sanitize_for_serialization


class PublishDataResponse(SdkResponse):

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    sensitive_list = []

    openapi_types = {
        'asset_id': 'str',
        'version': 'str'
    }

    attribute_map = {
        'asset_id': 'asset_id',
        'version': 'version'
    }

    def __init__(self, asset_id=None, version=None):
        """PublishDataResponse

        The model defined in huaweicloud sdk

        :param asset_id: 资产id
        :type asset_id: str
        :param version: 资产版本
        :type version: str
        """
        
        super(PublishDataResponse, self).__init__()

        self._asset_id = None
        self._version = None
        self.discriminator = None

        if asset_id is not None:
            self.asset_id = asset_id
        if version is not None:
            self.version = version

    @property
    def asset_id(self):
        """Gets the asset_id of this PublishDataResponse.

        资产id

        :return: The asset_id of this PublishDataResponse.
        :rtype: str
        """
        return self._asset_id

    @asset_id.setter
    def asset_id(self, asset_id):
        """Sets the asset_id of this PublishDataResponse.

        资产id

        :param asset_id: The asset_id of this PublishDataResponse.
        :type asset_id: str
        """
        self._asset_id = asset_id

    @property
    def version(self):
        """Gets the version of this PublishDataResponse.

        资产版本

        :return: The version of this PublishDataResponse.
        :rtype: str
        """
        return self._version

    @version.setter
    def version(self, version):
        """Sets the version of this PublishDataResponse.

        资产版本

        :param version: The version of this PublishDataResponse.
        :type version: str
        """
        self._version = version

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                if attr in self.sensitive_list:
                    result[attr] = "****"
                else:
                    result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        import simplejson as json
        if six.PY2:
            import sys
            reload(sys)
            sys.setdefaultencoding("utf-8")
        return json.dumps(sanitize_for_serialization(self), ensure_ascii=False)

    def __repr__(self):
        """For `print`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, PublishDataResponse):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other

==> huaweicloudsdkeihealth-3.1.38-py2.py3-none-any.whl: huaweicloudsdkeihealth/v1/model/publish_data_response.py <==
# coding: utf-8

import re
import six


from huaweicloudsdkcore.sdk_response import SdkResponse
from huaweicloudsdkcore.utils.http_utils import sanitize_for_serialization


class PublishDataResponse(SdkResponse):

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    sensitive_list = []

    openapi_types = {
        'id': 'str',
        'version': 'str'
    }

    attribute_map = {
        'id': 'id',
        'version': 'version'
    }

    def __init__(self, id=None, version=None):
        """PublishDataResponse

        The model defined in huaweicloud sdk

        :param id: 资产id
        :type id: str
        :param version: 资产版本
        :type version: str
        """
        
        super(PublishDataResponse, self).__init__()

        self._id = None
        self._version = None
        self.discriminator = None

        if id is not None:
            self.id = id
        if version is not None:
            self.version = version

    @property
    def id(self):
        """Gets the id of this PublishDataResponse.

        资产id

        :return: The id of this PublishDataResponse.
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this PublishDataResponse.

        资产id

        :param id: The id of this PublishDataResponse.
        :type id: str
        """
        self._id = id

    @property
    def version(self):
        """Gets the version of this PublishDataResponse.

        资产版本

        :return: The version of this PublishDataResponse.
        :rtype: str
        """
        return self._version

    @version.setter
    def version(self, version):
        """Sets the version of this PublishDataResponse.

        资产版本

        :param version: The version of this PublishDataResponse.
        :type version: str
        """
        self._version = version

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                if attr in self.sensitive_list:
                    result[attr] = "****"
                else:
                    result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        import simplejson as json
        if six.PY2:
            import sys
            reload(sys)
            sys.setdefaultencoding("utf-8")
        return json.dumps(sanitize_for_serialization(self), ensure_ascii=False)

    def __repr__(self):
        """For `print`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, PublishDataResponse):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
